==> qcad_1.3.3.orig.tar.gz: qcad-1.3.3.orig/rtoolbar.cpp <==
/***************************************************************************
                          rtoolbar.cpp  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/


/****************************************************************************
** rtoolbar.cpp 1998/09/04 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#include "rtoolbar.h"

#include <qdrawutil.h>

#include "rappwin.h"
#include "reventdef.h"
#include "rgraphic.h"
#include "rpainter.h"

// Constructor:
//
RToolBar::RToolBar(const char* _label, QMainWindow *_parent,
                   QMainWindow::ToolBarDock _dock, 
                   bool _newLine,
                   const char* _name)
:QToolBar(_label, _parent, 
          _dock,
          _newLine, _name)
{
  
}



// Destructor:
//
RToolBar::~RToolBar()
{

}


// Mouse Release event:
//
void 
RToolBar::mouseReleaseEvent(QMouseEvent* _ev)
{
  QToolBar::mouseReleaseEvent(_ev);
  
  if(_ev->button()==RightButton) {
    //RAppWin::getRAppWin()->changeMenu(TOOLBAR_MAIN);
    if(RAppWin::getRAppWin()->currentDoc()) {
      RAppWin::getRAppWin()->currentDoc()->distributeEvent(REVENT_RBUTTONUP);
    }
  }
}



// Repaint:
//
void     
RToolBar::paintEvent(QPaintEvent*)
{
  RPainter paint;        // painter
  paint.begin(this);

  /*QBrush brush(backgroundColor());

  qDrawWinPanel(&paint, 
                0, 0, width(), height(), 
                colorGroup(), 
                false,
                &brush);*/

  //paint.eraseRect(2, 2, width()-4, height()-4);
  /*paint.setPen(white);
  paint.drawLine(0, 0, width(), 0);
  paint.drawLine(0, 1, width(), 1);
  paint.drawLine(0, 0, 0, height());
  paint.drawLine(1, 0, 1, height());*/

  paint.end();
}



// EOF

==> qcad_1.5.4.orig.tar.gz: qcad-1.5.4/rtoolbar.cpp <==
/***************************************************************************
                          rtoolbar.cpp  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/


/****************************************************************************
** rtoolbar.cpp 1998/09/04 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#include "rtoolbar.h"

#include <qdrawutil.h>

#include "rappwin.h"
#include "reventdef.h"
#include "rgraphic.h"
#include "rpainter.h"

// Constructor:
//
RToolBar::RToolBar(const QString& _label, QMainWindow *_parent,
                   /*QMainWindow::ToolBarDock _dock,*/
                   bool _newLine,
                   const char* _name)
  :QToolBar(_label, _parent, _parent,
          /*_dock,*/
          _newLine, _name)
{
  
}



// Destructor:
//
RToolBar::~RToolBar()
{

}


// Mouse Release event:
//
void 
RToolBar::mouseReleaseEvent(QMouseEvent* _ev)
{
  QToolBar::mouseReleaseEvent(_ev);
  
  if(_ev->button()==RightButton ||
     (_ev->button()==LeftButton && (_ev->state()&ControlButton))) {
    //RAppWin::getRAppWin()->changeMenu(TOOLBAR_MAIN);
    if(RAppWin::getRAppWin()->currentDoc()) {
      RAppWin::getRAppWin()->currentDoc()->distributeEvent(REVENT_RBUTTONUP);
    }
  }
}



// Repaint:
//
void     
RToolBar::paintEvent(QPaintEvent *_ev)
{
  QToolBar::paintEvent( _ev );

  //RPainter paint;        // painter
  //paint.begin(this);

  /*QBrush brush(backgroundColor());

  qDrawWinPanel(&paint, 
                0, 0, width(), height(), 
                colorGroup(), 
                false,
                &brush);*/

  //paint.eraseRect(2, 2, width()-4, height()-4);
  /*paint.setPen(white);
  paint.drawLine(0, 0, width(), 0);
  paint.drawLine(0, 1, width(), 1);
  paint.drawLine(0, 0, 0, height());
  paint.drawLine(1, 0, 1, height());*/

  //paint.end();
}



// EOF
